@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2013 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: scriptLibInfo.php 5580 2013-01-27 12:21:02Z fishbone $
+ * @version    SVN: $Id: scriptLibInfo.php 5618 2013-02-07 14:59:49Z fishbone $
  * @link       http://www.magic3.org
  */
 class ScriptLibInfo
@@ -18,7 +18,8 @@ class ScriptLibInfo
 	private static $jQueryVer = 1.8;			// 使用するjQueryのバージョン
 	private static $jQueryVersionArray = array(	'1.6' => 'jquery-1.6.4.min.js',// jQueryバージョン
 												'1.7' => 'jquery-1.7.2.min.js',
-												'1.8' => 'jquery-1.8.3.min.js');
+												'1.8' => 'jquery-1.8.3.min.js',
+												'1.9' => 'jquery-1.9.1.min.js');
 	// Javascriptライブラリ(DBでの設定値)
 	// ベースライブラリ
 	const LIB_JQUERY				= 'jquery';
@@ -163,12 +164,6 @@ class ScriptLibInfo
 	const FCKEDITOR_DIRNAME				= 'fckeditor2.6.6';				// FCKEditor
 	
 	// ファイル名
-	const JQUERY_FILENAME			= 'jquery-1.2.6.pack.js';					// JQuery
-	const JQUERY_UI_CORE_FILENAME	= 'jquery-ui-core-1.5.2.packed.js';			// JQuery UI Core (core+Interaction)
-	const JQUERY_UI_PLUS_FILENAME	= 'jquery-ui-plus-1.5.2.packed.js';			// JQuery UI Core (widgets+effects)
-//	const JQUERY_L_FILENAME			= 'jquery-1.3.2.min.js';					// JQuery最新版(v1.3.2)、低速
-//	const JQUERY_L_FILENAME			= 'jquery-1.4.2.min.js';					// JQuery最新版(v1.4.2)
-//	const JQUERY_L_FILENAME			= 'jquery-1.5.2.min.js';					// JQuery最新版(v1.5.2)
 	const JQUERY_L_FILENAME			= 'jquery-1.6.4.min.js';					// JQuery最新版(v1.6.4)		// 2012/10/13～
 	const JQUERY_L_UI_CORE_FILENAME	= 'jquery-ui-core-1.8.2.min.js';			// JQuery UI Core (Core)
 	const JQUERY_L_UI_PLUS_FILENAME	= 'jquery-ui-plus-1.8.2.min.js';			// JQuery UI Plus (Interactions)
@@ -224,7 +219,7 @@ class ScriptLibInfo
 			if (empty($filename)) $filename = self::JQUERY_L_FILENAME;	// jQuery本体
 /*			switch (self::$jQueryVer){
 				case 0:		// デフォルトのとき
-					$filename = self::JQUERY_FILENAME;	// jquery
+					//$filename = self::JQUERY_FILENAME;	// jquery
 					break;
 				case 1:		// 最新のとき*/
 //					break;
