@@ -12,7 +12,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2013 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    Release 2.5.x SVN: $Id: global.php 5594 2013-02-01 08:20:27Z fishbone $
+ * @version    Release 2.5.x SVN: $Id: global.php 5616 2013-02-07 14:41:44Z fishbone $
  * @link       http://www.magic3.org
  */
 if (defined("M3_SYSTEM_DEFINE_INCLUDED")) return;
@@ -48,8 +48,8 @@ define('M3_ENCODING',	'UTF-8');	// 内部エンコーディング
 // ########## システム関係 ##########
 // システム基本情報
 define('M3_SYSTEM_NAME',			'Magic3');		// システム名称
-define('M3_SYSTEM_VERSION',			'2.5.6');		// システムのバージョン
-define('M3_SYSTEM_RELEASE_DATE',	'2013/1/23');	// システムのリリース日付
+define('M3_SYSTEM_VERSION',			'2.5.7');		// システムのバージョン
+define('M3_SYSTEM_RELEASE_DATE',	'2013/2/1');	// システムのリリース日付
 define('M3_SYSTEM_ID',				'M3');			// コンポーネント識別用ID
 define('M3_SYSTEM_DESCRIPTION',		'Magic3 is open source cms and web communication platform.');		// システムの説明
 define('M3_SYSTEM_MIN_MEMORY',		'16M');			// 最小メモリ使用量
@@ -104,6 +104,8 @@ define('M3_TAG_MACRO_LINKS',		'LINKS');								// 関連リンク置換キー
 define('M3_TAG_MACRO_CATEGORY',		'CATEGORY');							// カテゴリーリンク置換キー
 define('M3_TAG_MACRO_BLOG_LINK',	'BLOG_LINK');							// ブログリンク置換キー
 define('M3_TAG_MACRO_COMMENT_LINK',	'COMMENT_LINK');						// コメントリンク置換キー
+define('M3_TAG_MACRO_PERMALINK',	'PERMALINK');							// パーマリンク置換キー
+define('M3_TAG_MACRO_RATE',			'RATE');								// 評価機能置換キー
 define('M3_TAG_MACRO_WIDGET',		'WIDGET');								// ウィジェット埋め込みキー
 define('M3_TAG_MACRO_SITE_NAME',		'SITE_NAME');						// サイト情報置換キー(サイト名)
 define('M3_TAG_MACRO_SITE_URL',			'SITE_URL');						// サイト情報置換キー(URL)
@@ -126,6 +128,9 @@ define('M3_TAG_MACRO_CONTENT_BLOG_TITLE',	'CT_BLOG_TITLE');				// コンテン
 define('M3_TAG_MACRO_CONTENT_DESCRIPTION',	'CT_DESCRIPTION');				// コンテンツ置換キー(簡易説明)
 define('M3_TAG_MACRO_CONTENT_URL',			'CT_URL');						// コンテンツ置換キー(URL)
 define('M3_TAG_MACRO_CONTENT_IMAGE',		'CT_IMAGE');					// コンテンツ置換キー(画像)
+define('M3_TAG_MACRO_CONTENT_LOCATION',		'CT_LOCATION');					// コンテンツ置換キー(場所)
+define('M3_TAG_MACRO_CONTENT_CAMERA',		'CT_CAMERA');					// コンテンツ置換キー(カメラ)
+define('M3_TAG_MACRO_CONTENT_CATEGORY',		'CT_CATEGORY');					// コンテンツ置換キー(カテゴリー)
 define('M3_TAG_MACRO_COMMENT_DATE',			'CM_DATE');						// コメント置換キー(登録日)
 define('M3_TAG_MACRO_COMMENT_TIME',			'CM_TIME');						// コメント置換キー(登録時)
 define('M3_TAG_MACRO_COMMENT_AUTHOR',		'CM_AUTHOR');					// コメント置換キー(著者)
