@@ -10,9 +10,9 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2010 Magic3 Project.
+ * @copyright  Copyright 2006-2013 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: messageManager.php 5414 2012-11-27 02:46:34Z fishbone $
+ * @version    SVN: $Id: messageManager.php 5533 2013-01-09 13:29:32Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once(M3_SYSTEM_INCLUDE_PATH . '/common/core.php');
@@ -271,5 +271,40 @@ class MessageManager extends Core
 		if (!isset($value)) $value = self::DEFAULT_WORD_UNTITLED;		// 用語未設定
 		return $value;
 	}
+	/**
+	 * Joomla!用定義値を取得
+	 *
+	 * @param string $key    キーとなる項目値
+	 * @param string $lang	言語ID(空の場合は現在の言語ID)
+	 * @return string		値
+	 */
+	function getJoomlaText($key, $lang = '')
+	{
+		if (empty($lang)) $lang = $this->gEnv->getCurrentLanguage();
+		
+		// 初期データ読み込み
+		$this->_loadLangString($lang);
+		
+		$value = $this->_langStringArray[$key];
+		if (!isset($value)) $value = '';
+		return $value;
+	}
+	/**
+	 * Joomla!用定義値を変更
+	 *
+	 * @param string $key	キーとなる項目値
+	 * @param string $value	変更値
+	 * @param string $lang	言語ID(空の場合は現在の言語ID)
+	 * @return 				なし
+	 */
+	function replaceJoomlaText($key, $value, $lang = '')
+	{
+		if (empty($lang)) $lang = $this->gEnv->getCurrentLanguage();
+		
+		// 初期データ読み込み
+		$this->_loadLangString($lang);
+		
+		$this->_langStringArray[$key] = $value;
+	}
 }
 ?>
