@@ -9,7 +9,7 @@
 -- * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
 -- * @copyright  Copyright 2006-2011 Magic3 Project.
 -- * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
--- * @version    SVN: $Id: insert_base.sql 5156 2012-09-04 00:03:59Z fishbone $
+-- * @version    SVN: $Id: insert_base.sql 5238 2012-09-21 01:44:42Z fishbone $
 -- * @link       http://www.magic3.org
 -- *
 -- --------------------------------------------------------------------------------------------------
@@ -163,7 +163,6 @@ INSERT INTO _page_id
 ('photo',        1,       '',                '',            'フォトギャラリー',                   'フォトギャラリー画面用',               8,           0,              true,      true,      false,     true, false, false),
 ('contact',      1,       '',                '',            'お問い合わせ',                     'お問い合わせ画面用',                 9,           0,              true,      true,      false,     true, false, false),
 ('contact2',     1,       '',                '',            'お問い合わせ2',                    'お問い合わせ画面用',                 10,          0,              true,      true,      false,     true, false, false),
-('contact3',     1,       '',                '',            'お問い合わせ3',                    'お問い合わせ画面用',                 11,          0,              true,      true,      false,     true, false, false),
 ('reserve',      1,       '',                '',            '予約',                             '予約画面用',                         20,          0,              true,      true,      false,     true, false, false),
 ('search',       1,       '',                '',            '検索',                             '検索画面用',                         21,          0,              true,      true,      false,     true, false, false),
 ('user',         1,       '',                '',            'ユーザコンテンツ',                 'ユーザ作成コンテンツ用',             50,          0,              true,      true,      false,     true, false, false),
@@ -184,7 +183,6 @@ INSERT INTO _page_info
 ('index',     'photo',     'photo',         false),
 ('index',     'contact',   '',              true),
 ('index',     'contact2',  '',              true),
-('index',     'contact3',  '',              true),
 ('index',     'safe',      '',              true),
 ('m_index',   'content',   'content',       false),
 ('m_index',   'shop',      'product',       false),
@@ -205,7 +203,6 @@ INSERT INTO _page_info
 ('s_index',   'photo',     'photo',         false),
 ('s_index',   'contact',   '',              true),
 ('s_index',   'contact2',  '',              true),
-('s_index',   'contact3',  '',              true),
 ('s_index',   'safe',      '',              true),
 ('admin_index', 'front',   'dboard',        false),
 ('connector', 'content',   'content',       false);
