@@ -8,9 +8,9 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2011 Magic3 Project.
+ * @copyright  Copyright 2006-2013 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_mainConfigsysWidgetContainer.php 5128 2012-08-21 23:24:14Z fishbone $
+ * @version    SVN: $Id: admin_mainConfigsysWidgetContainer.php 5578 2013-01-27 07:35:05Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getCurrentWidgetContainerPath() .	'/admin_mainConfigsystemBaseWidgetContainer.php');
@@ -21,6 +21,8 @@ class admin_mainConfigsysWidgetContainer extends admin_mainConfigsystemBaseWidge
 	private $db;	// DB接続オブジェクト
 	private $adminTheme;		// 管理画面用jQueryUIテーマ
 	private $systemTemplate;// システム画面用テンプレート
+	private $jqueryVersionArray;	// jQueryバージョン選択用
+	private $jqueryVersion;			// jQueryバージョン
 	const CF_USE_SSL = 'use_ssl';		// SSL機能を使用するかどうか
 	const CF_USE_SSL_ADMIN = 'use_ssl_admin';		// 管理画面にSSL機能を使用するかどうか
 	const CAN_DETAIL_CONFIG	= 'permit_detail_config';				// 詳細設定が可能かどうか
@@ -48,11 +50,13 @@ class admin_mainConfigsysWidgetContainer extends admin_mainConfigsystemBaseWidge
 	const CF_ADMIN_DEFAULT_THEME = 'admin_default_theme';		// 管理画面用jQueryUIテーマ
 	const CF_HIERARCHICAL_PAGE = 'hierarchical_page';		// 階層化ページを使用するかどうか
 	const CF_MULTI_LANGUAGE = 'multi_language';			// 多言語対応
+	const CF_JQUERY_VERSION = 'jquery_version';			// jQueryバージョン
 	const INSTALL_DT = 'install_dt';		// システムインストール日時
 	const WORK_DIR = 'work_dir';			// 作業ディレクトリ
 	const WRITE_TEST_FILENAME = '_magic3_test';			// 書き込みテスト用ファイル名
 	const DEFAULT_THEME_DIR = '/ui/themes';				// jQueryUIテーマ格納ディレクトリ
 	const DEFAULT_SYSTEM_TEMPLATE_ID = '_system';				// デフォルトのシステム画面用テンプレート
+	const DEFAULT_JQUERY_VERSION = '1.8';				// デフォルトのjQueryバージョン
 	
 	/**
 	 * コンストラクタ
@@ -64,6 +68,11 @@ class admin_mainConfigsysWidgetContainer extends admin_mainConfigsystemBaseWidge
 		
 		// DB接続オブジェクト作成
 		$this->db = new admin_mainDb();
+		
+		// jQueryバージョン
+		$this->jqueryVersionArray = array(	array(	'name' => '1.6',	'value' => '1.6'),
+											array(	'name' => '1.7',	'value' => '1.7'),
+											array(	'name' => '1.8',	'value' => '1.8'));
 	}
 	/**
 	 * テンプレートファイルを設定
@@ -111,11 +120,12 @@ class admin_mainConfigsysWidgetContainer extends admin_mainConfigsystemBaseWidge
 		$siteSmartphoneInPublic = ($request->trimValueOf('item_site_smartphone_in_public') == 'on') ? 1 : 0;	// スマートフォン用サイトの公開状況
 		$configWindowOpenByTab = ($request->trimValueOf('item_config_window_open_by_tab') == 'on') ? 1 : 0;			// ウィジェット設定画面をタブで開くかどうか
 		$multiLanguage = ($request->trimValueOf('item_multi_language') == 'on') ? 1 : 0;			// 多言語対応
-			
 		$lang = $request->trimValueOf('item_lang');
 		$workDir = $request->trimValueOf('item_work_dir');
 		$this->systemTemplate = $request->trimValueOf('item_systemplate');	// システム画面用テンプレート
 		$this->adminTheme = $request->trimValueOf('item_theme');		// 管理画面用jQueryUIテーマ
+		$this->jqueryVersion = $request->trimValueOf('item_jquery_version');		// jQueryバージョン
+				
 		if ($act == 'update'){		// 設定更新のとき
 			$isErr = false;
 			if (!$isErr && !empty($lang)){
@@ -182,6 +192,9 @@ class admin_mainConfigsysWidgetContainer extends admin_mainConfigsystemBaseWidge
 			if (!$isErr){
 				if (!$this->db->updateSystemConfig(self::CF_ADMIN_DEFAULT_THEME, $this->adminTheme)) $isErr = true;// 管理画面用jQueryUIテーマ
 			}
+			if (!$isErr){
+				if (!$this->db->updateSystemConfig(self::CF_JQUERY_VERSION, $this->jqueryVersion)) $isErr = true;// jQueryバージョン
+			}
 			
 			if ($isErr){
 				$this->setMsg(self::MSG_APP_ERR, 'データ更新に失敗しました');
@@ -215,6 +228,8 @@ class admin_mainConfigsysWidgetContainer extends admin_mainConfigsystemBaseWidge
 			$multiLanguage = $this->gSystem->getSystemConfig(self::CF_MULTI_LANGUAGE);		// 多言語対応かどうか
 			$this->systemTemplate		= $this->db->getSystemConfig(self::CF_SYSTEM_TEMPLATE);// システム画面用テンプレート
 			$this->adminTheme = $this->db->getSystemConfig(self::CF_ADMIN_DEFAULT_THEME);		// 管理画面用jQueryUIテーマ
+			$this->jqueryVersion = $this->db->getSystemConfig(self::CF_JQUERY_VERSION);		// jQueryバージョン
+			if (empty($this->jqueryVersion)) $this->jqueryVersion = self::DEFAULT_JQUERY_VERSION;
 			
 			// メニュー項目の制御
 			//$this->db->updateMenuVisible(self::MENU_ITEM_DEVELOP, $canDetailConfig);			// 「開発」メニュー
@@ -268,6 +283,8 @@ class admin_mainConfigsysWidgetContainer extends admin_mainConfigsystemBaseWidge
 			$multiLanguage = $this->gSystem->getSystemConfig(self::CF_MULTI_LANGUAGE);		// 多言語対応かどうか
 			$this->systemTemplate		= $this->db->getSystemConfig(self::CF_SYSTEM_TEMPLATE);// システム画面用テンプレート
 			$this->adminTheme = $this->db->getSystemConfig(self::CF_ADMIN_DEFAULT_THEME);		// 管理画面用jQueryUIテーマ
+			$this->jqueryVersion = $this->db->getSystemConfig(self::CF_JQUERY_VERSION);		// jQueryバージョン
+			if (empty($this->jqueryVersion)) $this->jqueryVersion = self::DEFAULT_JQUERY_VERSION;
 		}
 		// 言語選択メニューを作成
 		$this->db->getLangs($this->gSystem->getSystemLanguages(), array($this, 'langLoop'));
@@ -278,6 +295,9 @@ class admin_mainConfigsysWidgetContainer extends admin_mainConfigsystemBaseWidge
 		// jQueryUIテーマ選択メニュー作成
 		$this->createThemeMenu($this->gEnv->getSystemRootPath() . self::DEFAULT_THEME_DIR);
 		
+		// jQueryバージョン選択メニュー作成
+		$this->createJqueryVerMenu();
+		
 		// サイトURL
 		$this->tmpl->addVar("_widget", "site_url", $this->gEnv->getRootUrl());
 		$this->tmpl->addVar("_widget", "pc_access_url", $this->gEnv->getDefaultUrl());
@@ -676,5 +696,28 @@ class admin_mainConfigsysWidgetContainer extends admin_mainConfigsystemBaseWidge
 		$this->tmpl->parseTemplate('systemplate_list', 'a');
 		return true;
 	}
+	/**
+	 * jQueryのバージョン選択メニューを作成
+	 *
+	 * @return 					なし
+	 */
+	function createJqueryVerMenu()
+	{
+		for ($i = 0; $i < count($this->jqueryVersionArray); $i++){
+			$value = $this->jqueryVersionArray[$i]['value'];
+			$name = $this->jqueryVersionArray[$i]['name'];
+			
+			$selected = '';
+			if ($value == $this->jqueryVersion) $selected = 'selected';
+			
+			$row = array(
+				'value'    => $this->convertToDispString($value),
+				'name'     => $this->convertToDispString($name),
+				'selected' => $selected			// 選択中かどうか
+			);
+			$this->tmpl->addVars('jquery_version_list', $row);
+			$this->tmpl->parseTemplate('jquery_version_list', 'a');
+		}
+	}
 }
 ?>
