@@ -8,9 +8,9 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2012 Magic3 Project.
+ * @copyright  Copyright 2006-2013 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_photo_mainConfigWidgetContainer.php 4662 2012-02-05 10:48:37Z fishbone $
+ * @version    SVN: $Id: admin_photo_mainConfigWidgetContainer.php 5603 2013-02-06 15:20:22Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getCurrentWidgetContainerPath() . '/admin_photo_mainBaseWidgetContainer.php');
@@ -69,6 +69,17 @@ class admin_photo_mainConfigWidgetContainer extends admin_photo_mainBaseWidgetCo
 		$thumbnailCrop = ($request->trimValueOf('item_thumbnail_crop') == 'on') ? 1 : 0;		// 切り取りサムネール
 		$thumbBgColor = $request->trimValueOf('item_bg_color');		// サムネール背景色
 		$categoryPassword = ($request->trimValueOf('item_category_password') == 'on') ? 1 : 0;		// 画像カテゴリーパスワード制限
+		$onlineShop = ($request->trimValueOf('item_online_shop') == 'on') ? 1 : 0;		// オンラインショップ連携
+		$layoutViewDetail = $request->valueOf('item_layout_view_detail');					// コンテンツレイアウト(詳細表示)
+		
+		$usePhotoDate	= ($request->trimValueOf('item_use_photo_date') == 'on') ? 1 : 0;				// 画像情報(撮影日)を使用
+		$usePhotoLocation	= ($request->trimValueOf('item_use_photo_location') == 'on') ? 1 : 0;			// 画像情報(撮影場所)を使用
+		$usePhotoCamera	= ($request->trimValueOf('item_use_photo_camera') == 'on') ? 1 : 0;			// 画像情報(カメラ)を使用
+		$usePhotoDescription = ($request->trimValueOf('item_use_photo_description') == 'on') ? 1 : 0;	// 画像情報(説明)を使用
+		$usePhotoKeyword	= ($request->trimValueOf('item_use_photo_keyword') == 'on') ? 1 : 0;			// 画像情報(検索キーワード)を使用
+		$usePhotoCategory	= ($request->trimValueOf('item_use_photo_category') == 'on') ? 1 : 0;		// 画像情報(カテゴリー)を使用
+		$usePhotoRate	= ($request->trimValueOf('item_use_photo_rate') == 'on') ? 1 : 0;				// 画像情報(評価)を使用
+		$htmlPhotoDescription	= ($request->trimValueOf('item_html_photo_description') == 'on') ? 1 : 0;	// HTML形式の画像情報(説明)
 		
 		$imageSize	= $request->trimValueOf('item_image_size');		// 公開画像サイズ
 		$thumbnailSize	= $request->trimValueOf('item_thumbnail_size');		// サムネール画像サイズ
@@ -86,6 +97,35 @@ class admin_photo_mainConfigWidgetContainer extends admin_photo_mainBaseWidgetCo
 			if ($this->getMsgCount() == 0){			// エラーのないとき
 				$isErr = false;
 				
+				if (empty($layoutViewDetail)) $layoutViewDetail = photo_mainCommonDef::DEFAULT_LAYOUT_VIEW_DETAIL;
+				
+				$updateValues = array(	photo_mainCommonDef::CF_PHOTO_LIST_ITEM_COUNT	=> $listViewCount,		// 画像一覧表示数
+										photo_mainCommonDef::CF_PHOTO_LIST_ORDER		=> $listViewOrder,		// 画像一覧表示順
+										photo_mainCommonDef::CF_PHOTO_LIST_SORT_KEY		=> $this->sortKey,		// 画像一覧ソートキー
+										photo_mainCommonDef::CF_IMAGE_CATEGORY_COUNT	=> $categoryCount,		// 画像カテゴリー数
+										photo_mainCommonDef::CF_PHOTO_TITLE_SHORT_LENGTH	=> $titleLength,	// 画像タイトル文字数
+										photo_mainCommonDef::CF_IMAGE_PROTECT_COPYRIGHT	=> $protectCopyright,	// 著作権保護
+										photo_mainCommonDef::CF_THUMBNAIL_CROP			=> $thumbnailCrop,		// 切り取りサムネール
+										photo_mainCommonDef::CF_THUMBNAIL_BG_COLOR		=> $thumbBgColor,		// サムネール背景色
+										photo_mainCommonDef::CF_PHOTO_CATEGORY_PASSWORD	=> $categoryPassword,	// 画像カテゴリーパスワード制限
+										photo_mainCommonDef::CF_ONLINE_SHOP				=> $onlineShop,			// オンラインショップ機能
+										photo_mainCommonDef::CF_LAYOUT_VIEW_DETAIL		=> $layoutViewDetail,	// コンテンツレイアウト(詳細表示)
+										
+										photo_mainCommonDef::CF_USE_PHOTO_DATE			=> $usePhotoDate,				// 画像情報(撮影日)を使用
+										photo_mainCommonDef::CF_USE_PHOTO_LOCATION			=> $usePhotoLocation,			// 画像情報(撮影場所)を使用
+										photo_mainCommonDef::CF_USE_PHOTO_CAMERA		=> $usePhotoCamera,			// 画像情報(カメラ)を使用
+										photo_mainCommonDef::CF_USE_PHOTO_DESCRIPTION	=> $usePhotoDescription,	// 画像情報(説明)を使用
+										photo_mainCommonDef::CF_USE_PHOTO_KEYWORD		=> $usePhotoKeyword,			// 画像情報(検索キーワード)を使用
+										photo_mainCommonDef::CF_USE_PHOTO_CATEGORY		=> $usePhotoCategory,		// 画像情報(カテゴリー)を使用
+										photo_mainCommonDef::CF_USE_PHOTO_RATE			=> $usePhotoRate,				// 画像情報(評価)を使用
+										photo_mainCommonDef::CF_HTML_PHOTO_DESCRIPTION	=> $htmlPhotoDescription,	// HTML形式の画像情報(説明)
+										
+										photo_mainCommonDef::CF_IMAGE_SIZE				=> $imageSize,	// 公開画像サイズ
+										photo_mainCommonDef::CF_THUMBNAIL_SIZE			=> $thumbnailSize,	// サムネール画像サイズ
+										photo_mainCommonDef::CF_DEFAULT_IMAGE_SIZE		=> $defaultImageSize,	// デフォルト公開画像サイズ
+										photo_mainCommonDef::CF_DEFAULT_THUMBNAIL_SIZE	=> $defaultThumbnailSize);	// デフォルトサムネール画像サイズ
+				$ret = $this->_updateConfig($updateValues);
+				/*
 				if (!$isErr){
 					if (!self::$_mainDb->updateConfig(photo_mainCommonDef::CF_PHOTO_LIST_ITEM_COUNT, $listViewCount)) $isErr = true;// 画像一覧表示数
 				}
@@ -113,6 +153,13 @@ class admin_photo_mainConfigWidgetContainer extends admin_photo_mainBaseWidgetCo
 				if (!$isErr){
 					if (!self::$_mainDb->updateConfig(photo_mainCommonDef::CF_PHOTO_CATEGORY_PASSWORD, $categoryPassword)) $isErr = true;		// 画像カテゴリーパスワード制限
 				}
+				if (!$isErr){
+					if (!self::$_mainDb->updateConfig(photo_mainCommonDef::CF_ONLINE_SHOP, $onlineShop)) $isErr = true;		// オンラインショップ機能
+				}
+				if (!$isErr){
+					$ret = self::$_mainDb->updateConfig(photo_mainCommonDef::CF_LAYOUT_VIEW_DETAIL, $layoutViewDetail);// コンテンツレイアウト(詳細表示)
+				}																							
+		
 				if (!$isErr){
 					if (!self::$_mainDb->updateConfig(photo_mainCommonDef::CF_IMAGE_SIZE, $imageSize)) $isErr = true;	// 公開画像サイズ
 				}
@@ -124,11 +171,12 @@ class admin_photo_mainConfigWidgetContainer extends admin_photo_mainBaseWidgetCo
 				}
 				if (!$isErr){
 					if (!self::$_mainDb->updateConfig(photo_mainCommonDef::CF_DEFAULT_THUMBNAIL_SIZE, $defaultThumbnailSize)) $isErr = true;	// デフォルトサムネール画像サイズ
-				}
-				if ($isErr){
-					$this->setMsg(self::MSG_APP_ERR, 'データ更新に失敗しました');
-				} else {
+				}*/
+				
+				if ($ret){
 					$this->setMsg(self::MSG_GUIDANCE, 'データを更新しました');
+				} else {
+					$this->setMsg(self::MSG_APP_ERR, 'データ更新に失敗しました(項目=' . $this->_getErrMessage() . ')');
 				}
 				// 値を再取得
 				$listViewCount	= self::$_mainDb->getConfig(photo_mainCommonDef::CF_PHOTO_LIST_ITEM_COUNT);		// 画像一覧表示数
@@ -142,6 +190,18 @@ class admin_photo_mainConfigWidgetContainer extends admin_photo_mainBaseWidgetCo
 				$thumbnailCrop	= self::$_mainDb->getConfig(photo_mainCommonDef::CF_THUMBNAIL_CROP);// 切り取りサムネール
 				$thumbBgColor	= self::$_mainDb->getConfig(photo_mainCommonDef::CF_THUMBNAIL_BG_COLOR);		// サムネール背景色
 				$categoryPassword	= self::$_mainDb->getConfig(photo_mainCommonDef::CF_PHOTO_CATEGORY_PASSWORD);		// 画像カテゴリーパスワード制限
+				$onlineShop	= self::$_mainDb->getConfig(photo_mainCommonDef::CF_ONLINE_SHOP);		// オンラインショップ機能
+				$layoutViewDetail = self::$_mainDb->getConfig(photo_mainCommonDef::CF_LAYOUT_VIEW_DETAIL);					// コンテンツレイアウト(詳細表示)
+				
+				$usePhotoDate	= self::$_mainDb->getConfig(photo_mainCommonDef::CF_USE_PHOTO_DATE);				// 画像情報(撮影日)を使用
+				$usePhotoLocation	= self::$_mainDb->getConfig(photo_mainCommonDef::CF_USE_PHOTO_LOCATION);			// 画像情報(撮影場所)を使用
+				$usePhotoCamera	= self::$_mainDb->getConfig(photo_mainCommonDef::CF_USE_PHOTO_CAMERA);			// 画像情報(カメラ)を使用
+				$usePhotoDescription = self::$_mainDb->getConfig(photo_mainCommonDef::CF_USE_PHOTO_DESCRIPTION);	// 画像情報(説明)を使用
+				$usePhotoKeyword	= self::$_mainDb->getConfig(photo_mainCommonDef::CF_USE_PHOTO_KEYWORD);			// 画像情報(検索キーワード)を使用
+				$usePhotoCategory	= self::$_mainDb->getConfig(photo_mainCommonDef::CF_USE_PHOTO_CATEGORY);		// 画像情報(カテゴリー)を使用
+				$usePhotoRate	= self::$_mainDb->getConfig(photo_mainCommonDef::CF_USE_PHOTO_RATE);				// 画像情報(評価)を使用
+				$htmlPhotoDescription	= self::$_mainDb->getConfig(photo_mainCommonDef::CF_HTML_PHOTO_DESCRIPTION);	// HTML形式の画像情報(説明)
+		
 				$imageSize			= self::$_mainDb->getConfig(photo_mainCommonDef::CF_IMAGE_SIZE);	// 公開画像サイズ
 				$thumbnailSize		= self::$_mainDb->getConfig(photo_mainCommonDef::CF_THUMBNAIL_SIZE);	// サムネール画像サイズ
 				$defaultImageSize	= self::$_mainDb->getConfig(photo_mainCommonDef::CF_DEFAULT_IMAGE_SIZE);		// デフォルト公開画像サイズ
@@ -162,6 +222,18 @@ class admin_photo_mainConfigWidgetContainer extends admin_photo_mainBaseWidgetCo
 			$thumbnailCrop	= self::$_mainDb->getConfig(photo_mainCommonDef::CF_THUMBNAIL_CROP);// 切り取りサムネール
 			$thumbBgColor	= self::$_mainDb->getConfig(photo_mainCommonDef::CF_THUMBNAIL_BG_COLOR);		// サムネール背景色
 			$categoryPassword	= self::$_mainDb->getConfig(photo_mainCommonDef::CF_PHOTO_CATEGORY_PASSWORD);		// 画像カテゴリーパスワード制限
+			$onlineShop	= self::$_mainDb->getConfig(photo_mainCommonDef::CF_ONLINE_SHOP);		// オンラインショップ機能
+			$layoutViewDetail = self::$_mainDb->getConfig(photo_mainCommonDef::CF_LAYOUT_VIEW_DETAIL);		// コンテンツレイアウト(詳細表示)
+			
+			$usePhotoDate	= self::$_mainDb->getConfig(photo_mainCommonDef::CF_USE_PHOTO_DATE);				// 画像情報(撮影日)を使用
+			$usePhotoLocation	= self::$_mainDb->getConfig(photo_mainCommonDef::CF_USE_PHOTO_LOCATION);			// 画像情報(撮影場所)を使用
+			$usePhotoCamera	= self::$_mainDb->getConfig(photo_mainCommonDef::CF_USE_PHOTO_CAMERA);			// 画像情報(カメラ)を使用
+			$usePhotoDescription = self::$_mainDb->getConfig(photo_mainCommonDef::CF_USE_PHOTO_DESCRIPTION);	// 画像情報(説明)を使用
+			$usePhotoKeyword	= self::$_mainDb->getConfig(photo_mainCommonDef::CF_USE_PHOTO_KEYWORD);			// 画像情報(検索キーワード)を使用
+			$usePhotoCategory	= self::$_mainDb->getConfig(photo_mainCommonDef::CF_USE_PHOTO_CATEGORY);		// 画像情報(カテゴリー)を使用
+			$usePhotoRate	= self::$_mainDb->getConfig(photo_mainCommonDef::CF_USE_PHOTO_RATE);				// 画像情報(評価)を使用
+			$htmlPhotoDescription	= self::$_mainDb->getConfig(photo_mainCommonDef::CF_HTML_PHOTO_DESCRIPTION);	// HTML形式の画像情報(説明)
+				
 			$imageSize			= self::$_mainDb->getConfig(photo_mainCommonDef::CF_IMAGE_SIZE);	// 公開画像サイズ
 			if (empty($imageSize)) $imageSize = photo_mainCommonDef::DEFAULT_IMAGE_SIZE;
 			$thumbnailSize	= self::$_mainDb->getConfig(photo_mainCommonDef::CF_THUMBNAIL_SIZE);	// サムネール画像サイズ
@@ -193,6 +265,20 @@ class admin_photo_mainConfigWidgetContainer extends admin_photo_mainBaseWidgetCo
 		$checked = '';
 		if (!empty($categoryPassword)) $checked = 'checked';
 		$this->tmpl->addVar("_widget", "category_password_checked", $checked);// 画像カテゴリーパスワード制限
+		$checked = '';
+		if (!empty($onlineShop)) $checked = 'checked';
+		$this->tmpl->addVar("_widget", "online_shop_checked", $checked);// オンラインショップ連携
+		$this->tmpl->addVar("_widget", "layout_view_detail", $layoutViewDetail);		// コンテンツレイアウト(詳細表示)
+		
+		$this->tmpl->addVar("_widget", "use_photo_date_checked", $usePhotoDate ? 'checked' : '');				// 画像情報(撮影日)を使用
+		$this->tmpl->addVar("_widget", "use_photo_location_checked", $usePhotoLocation ? 'checked' : '');			// 画像情報(撮影場所)を使用
+		$this->tmpl->addVar("_widget", "use_photo_camera_checked", $usePhotoCamera ? 'checked' : '');			// 画像情報(カメラ)を使用
+		$this->tmpl->addVar("_widget", "use_photo_description_checked", $usePhotoDescription ? 'checked' : '');	// 画像情報(説明)を使用
+		$this->tmpl->addVar("_widget", "use_photo_keyword_checked", $usePhotoKeyword ? 'checked' : '');			// 画像情報(検索キーワード)を使用
+		$this->tmpl->addVar("_widget", "use_photo_category_checked", $usePhotoCategory ? 'checked' : '');		// 画像情報(カテゴリー)を使用
+		$this->tmpl->addVar("_widget", "use_photo_rate_checked", $usePhotoRate ? 'checked' : '');				// 画像情報(評価)を使用
+		$this->tmpl->addVar("_widget", "html_photo_description_checked", $htmlPhotoDescription ? 'checked' : '');	// HTML形式の画像情報(説明)
+		
 		$this->tmpl->addVar("_widget", "image_size", $imageSize);// 公開画像サイズ
 		$this->tmpl->addVar("_widget", "thumbnail_size", $thumbnailSize);// サムネール画像サイズ
 		$this->tmpl->addVar("_widget", "default_image_size", $defaultImageSize);			// デフォルト公開画像サイズ
