@@ -8,9 +8,9 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2012 Magic3 Project.
+ * @copyright  Copyright 2006-2013 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_photo_mainImagebrowseWidgetContainer.php 4663 2012-02-10 01:58:00Z fishbone $
+ * @version    SVN: $Id: admin_photo_mainImagebrowseWidgetContainer.php 5612 2013-02-07 14:32:27Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getCurrentWidgetContainerPath() . '/admin_photo_mainBaseWidgetContainer.php');
@@ -194,12 +194,12 @@ class admin_photo_mainImagebrowseWidgetContainer extends admin_photo_mainBaseWid
 					$ret = self::$_mainDb->isExistsPhoto($filename);
 					if ($ret){
 						$errMessage = '画像ファイルが重複しています。';
-						$errDetail = '画像ID=' . $filename . ', オリジナルファイル名=' . $originalFilename;
+						$errDetail = '画像ID=' . $filename . ', 元のファイル名=' . $originalFilename;
 					}
 				}
 				
 				if (!$ret){		// 画像の重複がない場合
-					if (file_exists($filePath)) $this->writeError(__METHOD__, 'アップロード画像がすでに存在しています。新しい画像で置き換えます。', 1100, 'オリジナルファイル名=' . $originalFilename);
+					if (file_exists($filePath)) $this->writeError(__METHOD__, 'アップロード画像がすでに存在しています。新しい画像で置き換えます。', 1100, '元のファイル名=' . $originalFilename);
 
 					// アップされたファイルをコピー
 					$ret = move_uploaded_file($_FILES['Filedata']['tmp_name'], $filePath);
@@ -217,11 +217,11 @@ class admin_photo_mainImagebrowseWidgetContainer extends admin_photo_mainBaseWid
 							// 受付可能なファイルタイプかどうか
 							if (!in_array($imageMimeType, $this->permitMimeType)){
 								$isErr = true;	
-								$this->writeUserError(__METHOD__, 'アップロード画像のタイプが不正です。アカウント: ' . $account, 2200, 'オリジナルファイル名=' . $originalFilename);
+								$this->writeUserError(__METHOD__, 'アップロード画像のタイプが不正です。アカウント: ' . $account, 2200, '元のファイル名=' . $originalFilename);
 							}
 						} else {
 							$isErr = true;
-							$this->writeUserError(__METHOD__, 'アップロード画像が不正です。アカウント: ' . $account, 2200, 'オリジナルファイル名=' . $originalFilename);
+							$this->writeUserError(__METHOD__, 'アップロード画像が不正です。アカウント: ' . $account, 2200, '元のファイル名=' . $originalFilename);
 						}
 
 						if (!$isErr){
@@ -239,15 +239,15 @@ class admin_photo_mainImagebrowseWidgetContainer extends admin_photo_mainBaseWid
 								$camera = '';	// カメラ
 								$location = '';	// 場所
 								$date = $this->gEnv->getInitValueOfDate();		// 撮影日
-								$note = '';			// その他情報
+								$description = '';			// その他情報
 								$license = '';		// ライセンス
 								$keyword = '';		// 検索情報
 								$visible = true;	// 表示
 								$ret = self::$_mainDb->updatePhotoInfo(self::$_isLimitedUser, 0/*新規追加*/, $this->langId, $filename, $relativePath, $code, $imageMimeType,
-												$imageSize, $originalFilename, $filesize, $name, $camera, $location, $date, $note, $license, $this->userId, $keyword, $visible, 0/*ソート順*/, array()/*画像カテゴリー*/, $newSerial);
+												$imageSize, $originalFilename, $filesize, $name, $camera, $location, $date, $description, $license, $this->userId, $keyword, $visible, 0/*ソート順*/, array()/*画像カテゴリー*/, $newSerial);
 								if (!$ret){
 									$isErr = true;
-									$this->writeError(__METHOD__, 'アップロード画像のデータ登録に失敗しました。', 1100, 'オリジナルファイル名=' . $originalFilename);
+									$this->writeError(__METHOD__, 'アップロード画像のデータ登録に失敗しました。', 1100, '元のファイル名=' . $originalFilename);
 								}
 							}
 						}
@@ -495,7 +495,7 @@ class admin_photo_mainImagebrowseWidgetContainer extends admin_photo_mainBaseWid
 		$sortOrder = $request->trimValueOf('item_sort_order');			// 表示順
 		$location = $request->trimValueOf('item_location');		// 撮影場所
 		$camera = $request->trimValueOf('item_camera');		// カメラ
-		$note = $request->trimValueOf('item_note');			// メモ
+		$description = $request->valueOf('item_description');			// 画像説明
 		$keyword = $request->trimValueOf('item_keyword');	// 検索キーワード
 		$visible = ($request->trimValueOf('item_visible') == 'on') ? 1 : 0;		// チェックボックス
 		$photoDate = $request->trimValueOf('item_date');		// 撮影日
@@ -520,7 +520,7 @@ class admin_photo_mainImagebrowseWidgetContainer extends admin_photo_mainBaseWid
 			// エラーなしの場合は、データを更新
 			if ($this->getMsgCount() == 0){
 				$ret = self::$_mainDb->updatePhotoInfo(self::$_isLimitedUser, $this->serialNo/*更新*/, $this->langId, ''/*ファイル名*/, ''/*格納ディレクトリ*/, ''/*画像コード*/, ''/*画像MIMEタイプ*/,
-								''/*画像縦横サイズ*/, ''/*オリジナルファイル名*/, ''/*ファイルサイズ*/, $name, $camera, $location, $photoDate, $note, ''/*ライセンス*/, 0/*所有者*/, $keyword, $visible, $sortOrder, $categoryArray/*画像カテゴリー*/, $newSerial);
+								''/*画像縦横サイズ*/, ''/*元のファイル名*/, ''/*ファイルサイズ*/, $name, $camera, $location, $photoDate, $description, ''/*ライセンス*/, 0/*所有者*/, $keyword, $visible, $sortOrder, $categoryArray/*画像カテゴリー*/, $newSerial);
 				if ($ret){		// データ追加成功のとき
 					$this->setMsg(self::MSG_GUIDANCE, $this->_('Item updated.'));		// データを更新しました
 					$this->serialNo = $newSerial;
@@ -603,7 +603,7 @@ class admin_photo_mainImagebrowseWidgetContainer extends admin_photo_mainBaseWid
 				$sortOrder = $row['ht_sort_order'];		// ソート順
 				$location = $row['ht_location'];		// 撮影場所
 				$camera = $row['ht_camera'];		// カメラ
-				$note = $row['ht_note'];			// メモ
+				$description = $row['ht_description'];			// 画像説明
 				$keyword = $row['ht_keyword'];	// 検索キーワード
 				$visible = $row['ht_visible'];		// 公開
 				$photoDate = $this->convertToDispDate($row['ht_date']);	// 撮影日
@@ -641,9 +641,26 @@ class admin_photo_mainImagebrowseWidgetContainer extends admin_photo_mainBaseWid
 				$this->setAppErrorMsg($this->_('Can not find photo information.'));			// 画像情報が見つかりません
 			}
 		}
+		// 入力領域の表示制御
+		if (!self::$_configArray[photo_mainCommonDef::CF_USE_PHOTO_DATE]){
+			$this->tmpl->setAttribute('show_photo_date', 'visibility', 'hidden');			// 画像情報(撮影日)を使用
+			$this->tmpl->setAttribute('show_calender', 'visibility', 'hidden');				// カレンダーを作成しない
+		}
+		if (!self::$_configArray[photo_mainCommonDef::CF_USE_PHOTO_LOCATION]) $this->tmpl->setAttribute('show_photo_location', 'visibility', 'hidden');	// 画像情報(撮影場所)を使用
+		if (!self::$_configArray[photo_mainCommonDef::CF_USE_PHOTO_CAMERA]) $this->tmpl->setAttribute('show_photo_camera', 'visibility', 'hidden');		// 画像情報(カメラ)を使用
+		if (self::$_configArray[photo_mainCommonDef::CF_USE_PHOTO_DESCRIPTION]){
+			if (self::$_configArray[photo_mainCommonDef::CF_HTML_PHOTO_DESCRIPTION]) $this->tmpl->setAttribute('show_html_description', 'visibility', 'visible');		// HTMLエディターを表示
+		} else {
+			$this->tmpl->setAttribute('show_photo_description', 'visibility', 'hidden');	// 画像情報(説明)を使用
+		}
+		if (!self::$_configArray[photo_mainCommonDef::CF_USE_PHOTO_KEYWORD]) $this->tmpl->setAttribute('show_photo_keyword', 'visibility', 'hidden');	// 画像情報(検索キーワード)を使用
+		if (!self::$_configArray[photo_mainCommonDef::CF_USE_PHOTO_CATEGORY]) $this->tmpl->setAttribute('show_photo_category', 'visibility', 'hidden');	// 画像情報(カテゴリー)を使用
+		
 		// カテゴリーメニューを作成
-		$ret = self::$_mainDb->getAllCategory($this->langId, $allCategoryRows);
-		if ($ret) $this->createCategoryMenu($allCategoryRows, $categoryArray, $categoryCount);
+		if (self::$_configArray[photo_mainCommonDef::CF_USE_PHOTO_CATEGORY]){	// 画像情報(カテゴリー)を使用のとき
+			$ret = self::$_mainDb->getAllCategory($this->langId, $allCategoryRows);
+			if ($ret) $this->createCategoryMenu($allCategoryRows, $categoryArray, $categoryCount);
+		}
 		
 		// サムネールのURLの作成
 		$thumbnailUrlHtml = '';
@@ -673,12 +690,22 @@ class admin_photo_mainImagebrowseWidgetContainer extends admin_photo_mainBaseWid
 		$this->tmpl->addVar("_widget", "format", $this->convertToDispString($format));
 		$this->tmpl->addVar("_widget", "size", $this->convertToDispString($size));
 		$this->tmpl->addVar("_widget", "author", $this->convertToDispString($author));
-		$this->tmpl->addVar("_widget", "location", $this->convertToDispString($location));	// 撮影場所
-		$this->tmpl->addVar("_widget", "camera", $this->convertToDispString($camera));		// カメラ
-		$this->tmpl->addVar("_widget", "note", $this->convertToDispString($note));			// メモ
-		$this->tmpl->addVar("_widget", "keyword", $this->convertToDispString($keyword));	// 検索キーワード
-		$this->tmpl->addVar("_widget", "date", $photoDate);	// 撮影日
-		$this->tmpl->addVar('_widget', 'calendar_img', $this->getUrl($this->gEnv->getRootUrl() . self::CALENDAR_ICON_FILE));	// カレンダーアイコン
+		if (self::$_configArray[photo_mainCommonDef::CF_USE_PHOTO_LOCATION]){	// 画像情報(撮影場所)を使用のとき
+			$this->tmpl->addVar("show_photo_location", "location", $this->convertToDispString($location));	// 撮影場所
+		}
+		if (self::$_configArray[photo_mainCommonDef::CF_USE_PHOTO_CAMERA]){		// 画像情報(カメラ)を使用のとき
+			$this->tmpl->addVar("show_photo_camera", "camera", $this->convertToDispString($camera));		// カメラ
+		}
+		if (self::$_configArray[photo_mainCommonDef::CF_USE_PHOTO_DESCRIPTION]){		// 画像情報(説明)を使用のとき
+			$this->tmpl->addVar("show_photo_description", "description", $this->convertToDispString($description));
+		}
+		if (self::$_configArray[photo_mainCommonDef::CF_USE_PHOTO_KEYWORD]){	// 画像情報(検索キーワード)を使用のとき
+			$this->tmpl->addVar("show_photo_keyword", "keyword", $this->convertToDispString($keyword));	// 検索キーワード
+		}
+		if (self::$_configArray[photo_mainCommonDef::CF_USE_PHOTO_DATE]){		// 画像情報(撮影日)を使用のとき
+			$this->tmpl->addVar("show_photo_date", "date", $photoDate);	// 撮影日
+			$this->tmpl->addVar('show_photo_date', 'calendar_img', $this->getUrl($this->gEnv->getRootUrl() . self::CALENDAR_ICON_FILE));	// カレンダーアイコン
+		}
 		$this->tmpl->addVar('_widget', 'public_image_url', $this->convertToDispString($this->getUrl(photo_mainCommonDef::getPublicImageUrl($photoId))));	// 公開画像URL
 		$this->tmpl->addVar('_widget', 'thumbnail_url', $thumbnailUrlHtml);	// サムネール画像URL
 		$checkedStr = '';
@@ -783,7 +810,7 @@ class admin_photo_mainImagebrowseWidgetContainer extends admin_photo_mainBaseWid
 						$categoryStr .= $categoryRows[$j]['hc_name'];
 						if ($j < $categoryCount -1) $categoryStr .= ', ';
 					}
-					$filenameOption = '<br />オリジナルファイル名： ' . $this->convertToDispString($row['ht_original_filename']);		// ファイル名オプション
+					$filenameOption = '<br />元のファイル名： ' . $this->convertToDispString($row['ht_original_filename']);		// ファイル名オプション
 					$filenameOption .= '<br />タイトル名： ' . $this->convertToDispString($row['ht_name']);		// タイトル名
 					$filenameOption .= '<br />カテゴリー： ' . $this->convertToDispString($categoryStr);		// 所属カテゴリー
 					
@@ -1195,7 +1222,7 @@ class admin_photo_mainImagebrowseWidgetContainer extends admin_photo_mainBaseWid
 		$ret = $this->gInstance->getImageManager()->createDefaultThumb(M3_VIEW_TYPE_PHOTO, $photoId, $imagePath);
 		if (!$ret){
 			$this->writeError(__METHOD__, 'システム用画像ファイル作成に失敗しました。', 1100,
-								'オリジナルファイル名=' . $originalFilename);// 運用ログに記録
+								'元のファイル名=' . $originalFilename);// 運用ログに記録
 		}
 		
 		// ##### サムネール画像作成 #####
@@ -1213,7 +1240,7 @@ class admin_photo_mainImagebrowseWidgetContainer extends admin_photo_mainBaseWid
 			}
 			if (!$ret){
 				$this->writeError(__METHOD__, '画像ファイル作成に失敗しました。', 1100,
-									'オリジナルファイル名=' . $originalFilename . ', 画像ファイル=' . $thumbnailPath);// 運用ログに記録
+									'元のファイル名=' . $originalFilename . ', 画像ファイル=' . $thumbnailPath);// 運用ログに記録
 			}
 		}
 
@@ -1230,7 +1257,7 @@ class admin_photo_mainImagebrowseWidgetContainer extends admin_photo_mainBaseWid
 								photo_mainCommonDef::getPublicImagePath($photoId), self::DEFAULT_IMAGE_TYPE, $imageMaxSize);
 			if (!$ret){
 				$this->writeError(__METHOD__, '画像ファイル作成に失敗しました。', 1100,
-									'オリジナルファイル名=' . $originalFilename . ', 画像ファイル=' . $watermarkPath);// 運用ログに記録
+									'元のファイル名=' . $originalFilename . ', 画像ファイル=' . $watermarkPath);// 運用ログに記録
 			}
 		}
 		return $ret;
