@@ -8,9 +8,9 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2012 Magic3 Project.
+ * @copyright  Copyright 2006-2013 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: photo_mainCommonDef.php 4662 2012-02-05 10:48:37Z fishbone $
+ * @version    SVN: $Id: photo_mainCommonDef.php 5612 2013-02-07 14:32:27Z fishbone $
  * @link       http://www.magic3.org
  */
  
@@ -41,6 +41,7 @@ class photo_mainCommonDef
 	const DEFAULT_THUMBNAIL_SIZE		= 128;		// サムネール画像サイズ(設定されていないときのデフォルト値)
 	const DEFAULT_PHOTO_LIST_ORDER		= '0';		// デフォルトの画像一覧並び順(降順)
 	const DEFAULT_PHOTO_LIST_SORT_KEY	= 'index';	// デフォルトのソートキー
+	const DEFAULT_LAYOUT_VIEW_DETAIL	= '<table class="photo_info"><caption>画像情報</caption><tbody><tr><th>ID</th><td>[#CT_ID#]</td></tr><tr><th>タイトル</th><td>[#CT_TITLE#]&nbsp;[#PERMALINK#]</td></tr><tr><th>撮影者</th><td>[#CT_AUTHOR#]</td></tr><tr><th>撮影日</th><td>[#CT_DATE#]</td></tr><tr><th>場所</th><td>[#CT_LOCATION#]</td></tr><tr><th>カメラ</th><td>[#CT_CAMERA#]</td></tr><tr><th>説明</th><td>[#CT_DESCRIPTION#]</td></tr><tr><th>カテゴリー</th><td>[#CT_CATEGORY#]</td></tr><tr><th>評価</th><td>[#RATE#]</td></tr></tbody></table>';	// デフォルトのレイアウト(詳細画面)
 	
 	// DB定義値
 	const CF_THUMBNAIL_BG_COLOR			= 'thumbnail_bg_color';		// サムネール背景色
@@ -57,6 +58,15 @@ class photo_mainCommonDef
 	const CF_DEFAULT_IMAGE_SIZE			= 'default_image_size';				// デフォルト公開画像サイズ
 	const CF_DEFAULT_THUMBNAIL_SIZE		= 'default_thumbnail_size';			// デフォルトサムネール画像サイズ
 	const CF_THUMBNAIL_CROP				= 'thumbnail_crop';			// 切り取りサムネール
+	const CF_LAYOUT_VIEW_DETAIL			= 'layout_view_detail';		// デフォルトのレイアウト(詳細画面)
+	const CF_USE_PHOTO_DATE				= 'use_photo_date';			// 画像情報(撮影日)を使用
+	const CF_USE_PHOTO_LOCATION			= 'use_photo_location';			// 画像情報(撮影場所)を使用
+	const CF_USE_PHOTO_CAMERA			= 'use_photo_camera';			// 画像情報(カメラ)を使用
+	const CF_USE_PHOTO_DESCRIPTION		= 'use_photo_description';	// 画像情報(説明)を使用
+	const CF_USE_PHOTO_KEYWORD			= 'use_photo_keyword';		// 画像情報(検索キーワード)を使用
+	const CF_USE_PHOTO_CATEGORY			= 'use_photo_category';		// 画像情報(カテゴリー)を使用
+	const CF_USE_PHOTO_RATE				= 'use_photo_rate';			// 画像情報(評価)を使用
+	const CF_HTML_PHOTO_DESCRIPTION		= 'html_photo_description';		// HTML形式の画像情報(説明)
 	// Eコマース
 	const CF_SELL_PRODUCT_PHOTO			= 'sell_product_photo';		// フォト商品販売
 	const CF_SELL_PRODUCT_DOWNLOAD		= 'sell_product_download';	// ダウンロード商品販売
