@@ -8,9 +8,9 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2012 Magic3 Project.
+ * @copyright  Copyright 2006-2013 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: photo_mainTopWidgetContainer.php 5031 2012-07-12 01:07:39Z fishbone $
+ * @version    SVN: $Id: photo_mainTopWidgetContainer.php 5612 2013-02-07 14:32:27Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getCurrentWidgetContainerPath() .	'/photo_mainBaseWidgetContainer.php');
@@ -234,10 +234,10 @@ class photo_mainTopWidgetContainer extends photo_mainBaseWidgetContainer
 			$this->authCategory = array();		// 参照可能なカテゴリー
 				
 			// ブラウザのクライアントIDを取得
-			$cid = $this->gAccess->getClientId();
-			if (!empty($cid)){
+			$clientId = $this->gAccess->getClientId();
+			if (!empty($clientId)){
 				// クライアントパラメータオブジェクトを取得
-				$clientObj = $this->getClientParamObj($cid, $this->gEnv->getCurrentWidgetId());
+				$clientObj = $this->getClientParamObj($clientId, $this->gEnv->getCurrentWidgetId());
 				if (!empty($clientObj) && !empty($clientObj->authCategory)){
 					$this->authCategory = explode(',', $clientObj->authCategory);
 				}
@@ -254,7 +254,7 @@ class photo_mainTopWidgetContainer extends photo_mainBaseWidgetContainer
 					
 						// クライアントパラメータを更新
 						$clientObj->authCategory = implode(',', $this->authCategory);
-						$ret = $this->updateClientParamObj($cid, $this->gEnv->getCurrentWidgetId(), $clientObj);
+						$ret = $this->updateClientParamObj($clientId, $this->gEnv->getCurrentWidgetId(), $clientObj);
 						$this->setGuidanceMsg('認証に成功しました');
 					} else {
 						// 認証に失敗した画像カテゴリーは削除する
@@ -266,7 +266,7 @@ class photo_mainTopWidgetContainer extends photo_mainBaseWidgetContainer
 					
 						// クライアントパラメータを更新
 						$clientObj->authCategory = implode(',', $this->authCategory);
-						$ret = $this->updateClientParamObj($cid, $this->gEnv->getCurrentWidgetId(), $clientObj);
+						$ret = $this->updateClientParamObj($clientId, $this->gEnv->getCurrentWidgetId(), $clientObj);
 						$this->setAppErrorMsg('認証に失敗しました');
 					}
 				}
@@ -417,10 +417,10 @@ class photo_mainTopWidgetContainer extends photo_mainBaseWidgetContainer
 		if (!empty(self::$_configArray[photo_mainCommonDef::CF_PHOTO_CATEGORY_PASSWORD])){
 			// 参照可能なカテゴリーを取得
 			$this->authCategory = array();
-			$cid = $this->gAccess->getClientId();		// ブラウザのクライアントIDを取得
-			if (!empty($cid)){
+			$clientId = $this->gAccess->getClientId();		// ブラウザのクライアントIDを取得
+			if (!empty($clientId)){
 				// クライアントパラメータオブジェクトを取得
-				$clientObj = $this->getClientParamObj($cid, $this->gEnv->getCurrentWidgetId());
+				$clientObj = $this->getClientParamObj($clientId, $this->gEnv->getCurrentWidgetId());
 				if (!empty($clientObj) && !empty($clientObj->authCategory)){
 					$this->authCategory = explode(',', $clientObj->authCategory);
 				}
@@ -470,10 +470,10 @@ class photo_mainTopWidgetContainer extends photo_mainBaseWidgetContainer
 		if (!empty(self::$_configArray[photo_mainCommonDef::CF_PHOTO_CATEGORY_PASSWORD])){
 			// 参照可能なカテゴリーを取得
 			$this->authCategory = array();
-			$cid = $this->gAccess->getClientId();		// ブラウザのクライアントIDを取得
-			if (!empty($cid)){
+			$clientId = $this->gAccess->getClientId();		// ブラウザのクライアントIDを取得
+			if (!empty($clientId)){
 				// クライアントパラメータオブジェクトを取得
-				$clientObj = $this->getClientParamObj($cid, $this->gEnv->getCurrentWidgetId());
+				$clientObj = $this->getClientParamObj($clientId, $this->gEnv->getCurrentWidgetId());
 				if (!empty($clientObj) && !empty($clientObj->authCategory)){
 					$this->authCategory = explode(',', $clientObj->authCategory);
 				}
@@ -481,186 +481,210 @@ class photo_mainTopWidgetContainer extends photo_mainBaseWidgetContainer
 		}
 		
 		$ret = self::$_mainDb->getSearchPhotoInfo($this->photoId, $this->_langId, $row, $categoryRows);
-		if ($ret){
-			// カテゴリーのアクセスチェック
-			if (!is_null($this->authCategory)){
-				for ($i = 0; $i < count($categoryRows); $i++){
-					if (in_array($categoryRows[$i]['hc_id'], $this->authCategory)) break;
-				}
-				if ($i == count($categoryRows)){
-					$this->setUserErrorMsg('画像が見つかりません');
-					$this->writeUserError(__METHOD__, '不正な画像アクセスを検出しました。画像タイトル=' . $row['ht_name'], 2200, '公開画像ID=' . $this->photoId);
-					return;
-				}
-			}
-			
-			// URLパラメータ
-			$itemNo = $request->trimValueOf(M3_REQUEST_PARAM_ITEM_NO);		// 画像No
-			if (!ValueCheck::isNumeric($itemNo)) $itemNo = 1;
-			$keyword = $request->trimValueOf(M3_REQUEST_PARAM_KEYWORD);		// 検索キーワード
-			$pageNo = $request->trimIntValueOf(M3_REQUEST_PARAM_PAGE_NO, '1');				// ページ番号
-			$category = $request->trimValueOf('category');		// カテゴリー
-			$author = $request->trimValueOf('author');			// 著作者
-			$sort = $request->trimValueOf('sort');		// ソート順
-
-			// データエラーチェック
-			$this->checkInputValues($category, $author, $sort);
-			
-			// URLパラメータ作成
-			$urlParams = $this->createUrlParams($keyword, $category, $author, $sort);
-			
-			// キーワード分割
-			$parsedKeywords = $this->gInstance->getTextConvManager()->parseSearchKeyword($keyword);
-		
-			// ページ番号修正
-			$pageNo = intval(($itemNo -1) / $this->viewCount) + 1;
-		
-			$title = $alt = $row['ht_name'];
-			$author = $row['lu_name'];
-			$date = $row['ht_date'];		// 撮影日
-			
-			// 画像サイズ
-			$imageMaxSize = intval(self::$_configArray[photo_mainCommonDef::CF_DEFAULT_IMAGE_SIZE]);
-			if ($imageMaxSize <= 0) $imageMaxSize = photo_mainCommonDef::DEFAULT_IMAGE_SIZE;
-			list($width, $height) = explode('x', $row['ht_image_size']);
-			if ($width > $height){
-				$height = round(($height / $width) * $imageMaxSize);
-				$width = $imageMaxSize;
-			} else {
-				$width = round(($width / $height) * $imageMaxSize);
-				$height = $imageMaxSize;
-			}
-			if (empty($width) || empty($height)){
-				$width = $height = $imageMaxSize;
-			}
-			
-			// 詳細画像
-			$imagePath = photo_mainCommonDef::getPublicImagePath($this->photoId);
-			if (file_exists($imagePath)){
-				$imageUrl = photo_mainCommonDef::getPublicImageUrl($this->photoId);
-			} else {
-				$imageUrl = $this->notfoundThumbnailUrl;
-			}
-			
-			// パーマリンク
-			$permaUrl = $this->getUrl($this->gEnv->getDefaultUrl() . '?'. M3_REQUEST_PARAM_PHOTO_ID . '=' . $this->photoId);
-			$permaLink = '<a href="' . $this->convertUrlToHtmlEntity($permaUrl) . '"><img src="' . $this->getUrl($this->gEnv->getRootUrl() . self::PERMALINK_ICON_FILE) . 
-							'" width="' . photo_mainCommonDef::BUTTON_ICON_SIZE . '" height="' . photo_mainCommonDef::BUTTON_ICON_SIZE . '" title="パーマリンク" alt="パーマリンク" style="border:none;margin:0;padding:0;" /></a>';
-			
-			// 前後のリンクを取得
-			$this->startNo = $request->trimIntValueOf(M3_REQUEST_PARAM_ITEM_NO, '1');
-			$limitedCategory = $this->authCategory;
-			if (!is_null($limitedCategory) && count($limitedCategory) == 0) $limitedCategory = array('0');		// 空の場合はダミーのカテゴリーIDを追加
-			self::$_mainDb->searchPhotoItemByNo(3, $this->startNo -1, $this->_langId, null/*開始日時*/, null/*終了日時*/, $parsedKeywords/*キーワード*/, 
-					$this->categoryArray/*カテゴリー*/, $this->authorArray/*撮影者*/, $this->sortKey/*ソートキー*/, $this->sortDirection/*ソート方向*/,
-					array($this, 'prevNextListLoop'), $urlParams, $limitedCategory);
-		
-			// 戻り先一覧画面のURLを取得
-			$backUrl = $this->currentPageUrl;
-			if ($pageNo > 1) $backUrl .= '&' . M3_REQUEST_PARAM_PAGE_NO . '=' . $pageNo;
-			$backUrl .= $urlParams;
-			
-			// 画像カテゴリーを取得
-			$categoryStr = '';
-			for ($i = 0; $i < count($categoryRows); $i++){
-				if ($i > 0) $categoryStr .= ', ';
-				$categoryStr .= $categoryRows[$i]['hc_name'];
-			}
-			
-			// 投票状況
-			$rateDisabled = '';
-			$ip = $this->gRequest->trimServerValueOf('REMOTE_ADDR');
-			$isRegistered = $commentDb->isExistsComment($this->photoId, $ip, $this->_langId);
-			if ($isRegistered) $rateDisabled = 'disabled';
-			
-			// コメントを取得
-			$commentDb->getCommentByPublicPhotoId(photo_mainCommonDef::DEFAULT_COMMENT_COUNT, 1/**/, $this->photoId, $this->_langId, array($this, 'commentListLoop'));
-			if (count($this->serialArray) == 0) $this->tmpl->setAttribute('itemlist', 'visibility', 'hidden');
-			
-			// 画像情報を表示
-			$this->tmpl->setAttribute('photo_info_script', 'visibility', 'visible');
-			$this->tmpl->setAttribute('photo_info_area', 'visibility', 'visible');
-			
-			// オンラインショップ機能
-			if (!empty(self::$_configArray[photo_mainCommonDef::CF_ONLINE_SHOP])){
-				$this->tmpl->setAttribute('product_script', 'visibility', 'visible');
-				$this->tmpl->setAttribute('product_info', 'visibility', 'visible');
-				
-				// フォト商品の表示
-				if (!empty(self::$_configArray[photo_mainCommonDef::CF_SELL_PRODUCT_PHOTO])){		// フォト関連商品販売をする場合
-					$this->ecObj = $this->gInstance->getObject(self::PRICE_OBJ_ID);
-					
-					// 通貨情報を取得
-					$ret = $this->ecObj->db->getCurrency(self::DEFAULT_CURRENCY, $this->_langId, $currencyRow);
-					if ($ret){
-						$this->prePrice = $this->convertToDispString($currencyRow['cu_symbol']);
-						$this->postPrice = $this->convertToDispString($currencyRow['cu_post_symbol']);
-					}
-					
-					self::$_mainDb->getAllProduct($this->_langId, array($this, 'productListLoop'));
-					if (empty($this->isExistsProduct)) $this->tmpl->setAttribute('product_list', 'visibility', 'hidden'); 		// 商品が存在しないとき
-				} else {
-					$this->tmpl->setAttribute('product_list', 'visibility', 'hidden');
-				}
-				
-				// ダウンロード販売の表示
-				if (!empty(self::$_configArray[photo_mainCommonDef::CF_SELL_PRODUCT_DOWNLOAD])){		// ダウンロード販売をする場合
-					// ダウンロード権のチェック
-					$canDownloadImage = false;
-					$ret = self::$_mainDb->getContentAccess($this->_userId, M3_VIEW_TYPE_PHOTO, $row['ht_id'], $accessRow);
-					if ($ret){
-						if ($accessRow['cs_download']) $canDownloadImage = true;
-					}
-				
-					if ($canDownloadImage){
-						$this->tmpl->setAttribute('product_download', 'visibility', 'visible');
-					} else {
-						$this->tmpl->setAttribute('product_cart', 'visibility', 'visible');
-					}
-				} else {
-					$this->tmpl->setAttribute('download_area', 'visibility', 'hidden');
-				}
-			}
-			// 画像情報
-			$this->tmpl->addVar("photo_info_area", "photo_id", $this->photoId);
-			$this->tmpl->addVar("photo_info_area", "author", $this->convertToDispString($author));
-			$this->tmpl->addVar("photo_info_area", "place", $this->convertToDispString($row['ht_location']));
-			$this->tmpl->addVar("photo_info_area", "camera", $this->convertToDispString($row['ht_camera']));
-			$this->tmpl->addVar("photo_info_area", "note", $this->convertToDispString($row['ht_note']));
-			$this->tmpl->addVar("photo_info_area", "date", $this->convertToDispDate($date));
-			$this->tmpl->addVar("photo_info_area", "category", $this->convertToDispString($categoryStr));
-			$this->tmpl->addVar("photo_info_area", "img_url", $this->getUrl($imageUrl));
-			$this->tmpl->addVar("photo_info_area", "width", $width);
-			$this->tmpl->addVar("photo_info_area", "height", $height);
-			$this->tmpl->addVar("photo_info_area", "title", $this->convertToDispString($title));
-			$this->tmpl->addVar("photo_info_area", "permalink", $permaLink);
-			$this->tmpl->addVar("photo_info_area", "alt", $this->convertToDispString($alt));
-			$this->tmpl->addVar("photo_info_area", "back_url", $this->convertUrlToHtmlEntity($this->getUrl($backUrl, true/*リンク用*/)));// 「戻る」リンク
-			$this->tmpl->addVar("photo_info_area", "back_img_url", $this->getUrl($this->gEnv->getRootUrl() . self::BACK_ICON_FILE));// 「戻る」アイコン
-			$this->tmpl->addVar("photo_info_area", "icon_size", photo_mainCommonDef::BUTTON_ICON_SIZE);
-			$this->tmpl->addVar("photo_info_area", "back_title", self::BACK_BUTTON_TITLE);
-			$this->tmpl->addVar("photo_info_area", "back_alt", self::BACK_BUTTON_TITLE);
-			// スクリプト部
-			$this->tmpl->addVar('photo_info_script', 'raty_image_url', $this->getUrl($this->gEnv->getScriptsUrl() . self::RATY_IMAGE_DIR));	// jquery.raty画像パス
-			$this->tmpl->addVar("photo_info_script", "init_rate", $this->convertToDispString($row['ht_rate_average']));		// 評価値
-			$this->tmpl->addVar("photo_info_area", "rate_disabled", $rateDisabled);			// 「投票する」ボタン使用可否
-			$this->tmpl->addVar("photo_info_area", "comment_count", count($this->serialArray));		// コメント数
-			
-			// ハッシュキー作成
-			$postTicket = md5(time() . $this->gAccess->getAccessLogSerialNo());
-			$request->setSessionValue(M3_SESSION_POST_TICKET, $postTicket);		// セッションに保存
-			$this->tmpl->addVar("photo_info_area", "ticket", $postTicket);				// 画面に書き出し
-				
-			// ビューカウントを更新
-			if (!$this->gEnv->isSystemManageUser()){		// システム運用者以上の場合はカウントしない
-				// 詳細な参照情報
-				$this->gInstance->getAnalyzeManager()->updateContentViewCount(photo_mainCommonDef::REF_TYPE_CONTENT, $row['ht_id'], $this->currentDay, $this->currentHour);
-				
-				// 画像情報の参照数更新
-				self::$_mainDb->updatePhotoInfoViewCount($row['ht_serial']);
-			}
-		} else {
+		if (!$ret){
 			$this->setUserErrorMsg('画像が見つかりません');
+			return;
+		}
+		// カテゴリーのアクセスチェック
+		if (!is_null($this->authCategory)){
+			for ($i = 0; $i < count($categoryRows); $i++){
+				if (in_array($categoryRows[$i]['hc_id'], $this->authCategory)) break;
+			}
+			if ($i == count($categoryRows)){
+				$this->setUserErrorMsg('画像が見つかりません');
+				$this->writeUserError(__METHOD__, '不正な画像アクセスを検出しました。画像タイトル=' . $row['ht_name'], 2200, '公開画像ID=' . $this->photoId);
+				return;
+			}
+		}
+		
+		// URLパラメータ
+		$itemNo = $request->trimValueOf(M3_REQUEST_PARAM_ITEM_NO);		// 画像No
+		if (!ValueCheck::isNumeric($itemNo)) $itemNo = 1;
+		$keyword = $request->trimValueOf(M3_REQUEST_PARAM_KEYWORD);		// 検索キーワード
+		$pageNo = $request->trimIntValueOf(M3_REQUEST_PARAM_PAGE_NO, '1');				// ページ番号
+		$category = $request->trimValueOf('category');		// カテゴリー
+		$author = $request->trimValueOf('author');			// 著作者
+		$sort = $request->trimValueOf('sort');		// ソート順
+
+		// データエラーチェック
+		$this->checkInputValues($category, $author, $sort);
+		
+		// URLパラメータ作成
+		$urlParams = $this->createUrlParams($keyword, $category, $author, $sort);
+		
+		// キーワード分割
+		$parsedKeywords = $this->gInstance->getTextConvManager()->parseSearchKeyword($keyword);
+	
+		// ページ番号修正
+		$pageNo = intval(($itemNo -1) / $this->viewCount) + 1;
+	
+		$title = $alt = $row['ht_name'];
+		$author = $row['lu_name'];
+		$date = $row['ht_date'];		// 撮影日
+		
+		// 画像サイズ
+		$imageMaxSize = intval(self::$_configArray[photo_mainCommonDef::CF_DEFAULT_IMAGE_SIZE]);
+		if ($imageMaxSize <= 0) $imageMaxSize = photo_mainCommonDef::DEFAULT_IMAGE_SIZE;
+		list($width, $height) = explode('x', $row['ht_image_size']);
+		if ($width > $height){
+			$height = round(($height / $width) * $imageMaxSize);
+			$width = $imageMaxSize;
+		} else {
+			$width = round(($width / $height) * $imageMaxSize);
+			$height = $imageMaxSize;
+		}
+		if (empty($width) || empty($height)){
+			$width = $height = $imageMaxSize;
+		}
+		
+		// 詳細画像
+		$imagePath = photo_mainCommonDef::getPublicImagePath($this->photoId);
+		if (file_exists($imagePath)){
+			$imageUrl = photo_mainCommonDef::getPublicImageUrl($this->photoId);
+		} else {
+			$imageUrl = $this->notfoundThumbnailUrl;
+		}
+		
+		// パーマリンク
+		$permaUrl = $this->getUrl($this->gEnv->getDefaultUrl() . '?'. M3_REQUEST_PARAM_PHOTO_ID . '=' . $this->photoId);
+		$permaLink = '<a href="' . $this->convertUrlToHtmlEntity($permaUrl) . '"><img src="' . $this->getUrl($this->gEnv->getRootUrl() . self::PERMALINK_ICON_FILE) . 
+						'" width="' . photo_mainCommonDef::BUTTON_ICON_SIZE . '" height="' . photo_mainCommonDef::BUTTON_ICON_SIZE . '" title="パーマリンク" alt="パーマリンク" style="border:none;margin:0;padding:0;" /></a>';
+		
+		// 前後のリンクを取得
+		$this->startNo = $request->trimIntValueOf(M3_REQUEST_PARAM_ITEM_NO, '1');
+		$limitedCategory = $this->authCategory;
+		if (!is_null($limitedCategory) && count($limitedCategory) == 0) $limitedCategory = array('0');		// 空の場合はダミーのカテゴリーIDを追加
+		self::$_mainDb->searchPhotoItemByNo(3, $this->startNo -1, $this->_langId, null/*開始日時*/, null/*終了日時*/, $parsedKeywords/*キーワード*/, 
+				$this->categoryArray/*カテゴリー*/, $this->authorArray/*撮影者*/, $this->sortKey/*ソートキー*/, $this->sortDirection/*ソート方向*/,
+				array($this, 'prevNextListLoop'), $urlParams, $limitedCategory);
+	
+		// 戻り先一覧画面のURLを取得
+		$backUrl = $this->currentPageUrl;
+		if ($pageNo > 1) $backUrl .= '&' . M3_REQUEST_PARAM_PAGE_NO . '=' . $pageNo;
+		$backUrl .= $urlParams;
+		
+		// 画像カテゴリーを取得
+		$categoryStr = '';
+		for ($i = 0; $i < count($categoryRows); $i++){
+			if ($i > 0) $categoryStr .= ', ';
+			$categoryStr .= $categoryRows[$i]['hc_name'];
+		}
+		
+		// 投票状況
+		$rateDisabled = '';
+		//$ip = $this->gRequest->trimServerValueOf('REMOTE_ADDR');
+		$clientId = $this->gAccess->getClientId();			// ブラウザのクライアントIDを取得
+		$isRegistered = $commentDb->isExistsComment($this->photoId, $clientId, $this->_langId);
+		if ($isRegistered) $rateDisabled = 'disabled';
+		
+		// コメントを取得
+		$commentDb->getCommentByPublicPhotoId(photo_mainCommonDef::DEFAULT_COMMENT_COUNT, 1/**/, $this->photoId, $this->_langId, array($this, 'commentListLoop'));
+		if (count($this->serialArray) == 0) $this->tmpl->setAttribute('itemlist', 'visibility', 'hidden');
+		
+		// 画像情報を表示
+		$this->tmpl->setAttribute('photo_info_script', 'visibility', 'visible');
+		$this->tmpl->setAttribute('photo_info_area', 'visibility', 'visible');
+		
+		// オンラインショップ機能
+		if (!empty(self::$_configArray[photo_mainCommonDef::CF_ONLINE_SHOP])){
+			$this->tmpl->setAttribute('product_script', 'visibility', 'visible');
+			$this->tmpl->setAttribute('product_info', 'visibility', 'visible');
+			
+			// フォト商品の表示
+			if (!empty(self::$_configArray[photo_mainCommonDef::CF_SELL_PRODUCT_PHOTO])){		// フォト関連商品販売をする場合
+				$this->ecObj = $this->gInstance->getObject(self::PRICE_OBJ_ID);
+				
+				// 通貨情報を取得
+				$ret = $this->ecObj->db->getCurrency(self::DEFAULT_CURRENCY, $this->_langId, $currencyRow);
+				if ($ret){
+					$this->prePrice = $this->convertToDispString($currencyRow['cu_symbol']);
+					$this->postPrice = $this->convertToDispString($currencyRow['cu_post_symbol']);
+				}
+				
+				self::$_mainDb->getAllProduct($this->_langId, array($this, 'productListLoop'));
+				if (empty($this->isExistsProduct)) $this->tmpl->setAttribute('product_list', 'visibility', 'hidden'); 		// 商品が存在しないとき
+			} else {
+				$this->tmpl->setAttribute('product_list', 'visibility', 'hidden');
+			}
+			
+			// ダウンロード販売の表示
+			if (!empty(self::$_configArray[photo_mainCommonDef::CF_SELL_PRODUCT_DOWNLOAD])){		// ダウンロード販売をする場合
+				// ダウンロード権のチェック
+				$canDownloadImage = false;
+				$ret = self::$_mainDb->getContentAccess($this->_userId, M3_VIEW_TYPE_PHOTO, $row['ht_id'], $accessRow);
+				if ($ret){
+					if ($accessRow['cs_download']) $canDownloadImage = true;
+				}
+			
+				if ($canDownloadImage){
+					$this->tmpl->setAttribute('product_download', 'visibility', 'visible');
+				} else {
+					$this->tmpl->setAttribute('product_cart', 'visibility', 'visible');
+				}
+			} else {
+				$this->tmpl->setAttribute('download_area', 'visibility', 'hidden');
+			}
+		}
+		// ##### HTMLタグで生成される文字列を埋め込む #####
+		// 「投票する」ボタン使用可否を設定
+		$contentParam = array();
+		$rateTag = '';
+		if (self::$_configArray[photo_mainCommonDef::CF_USE_PHOTO_RATE]){	// 画像情報(評価)を使用のとき
+			$rateTag = '<span id="photo_rating"></span><input id="photo_rate_send" type="button" class="button" value="投票する" ' . $rateDisabled . '/><span id="photo_rate_message"></span>';
+			
+		}
+		$contentParam[M3_TAG_MACRO_RATE] = $rateTag;
+		if (self::$_configArray[photo_mainCommonDef::CF_USE_PHOTO_DESCRIPTION] && // HTMLで画像説明を表示のとき
+			self::$_configArray[photo_mainCommonDef::CF_HTML_PHOTO_DESCRIPTION]) $contentParam[M3_TAG_MACRO_CONTENT_DESCRIPTION] = $row['ht_description'];
+		$contentParam[M3_TAG_MACRO_PERMALINK] = $permaLink;		// 画像情報(パーマリンク)
+		$contentText = $this->createDetailContent($contentParam);	// コンテンツレイアウトに埋め込む
+		
+		// Magic3マクロ変換。あらかじめ「CT_」タグをすべて取得する?
+		$contentInfo = array();
+		$contentInfo[M3_TAG_MACRO_CONTENT_ID] = $this->photoId;			// 画像情報(ID)
+		$contentInfo[M3_TAG_MACRO_CONTENT_TITLE] = $title;			// 画像情報(タイトル)
+		$contentInfo[M3_TAG_MACRO_CONTENT_AUTHOR] = $author;		// 画像情報(撮影者)
+		if (self::$_configArray[photo_mainCommonDef::CF_USE_PHOTO_DATE]) $contentInfo[M3_TAG_MACRO_CONTENT_DATE] = ($date == $this->gEnv->getInitValueOfDate() ? '' : $date);		// 画像情報(撮影日)
+		if (self::$_configArray[photo_mainCommonDef::CF_USE_PHOTO_LOCATION]) $contentInfo[M3_TAG_MACRO_CONTENT_LOCATION] = $row['ht_location'];		// 画像情報(撮影場所)
+		if (self::$_configArray[photo_mainCommonDef::CF_USE_PHOTO_CAMERA]) $contentInfo[M3_TAG_MACRO_CONTENT_CAMERA] = $row['ht_camera'];		// 画像情報(カメラ)
+		if (self::$_configArray[photo_mainCommonDef::CF_USE_PHOTO_DESCRIPTION] && 
+			!self::$_configArray[photo_mainCommonDef::CF_HTML_PHOTO_DESCRIPTION]) $contentInfo[M3_TAG_MACRO_CONTENT_DESCRIPTION] = $row['ht_description'];			// 画像情報(説明)
+		if (self::$_configArray[photo_mainCommonDef::CF_USE_PHOTO_CATEGORY]) $contentInfo[M3_TAG_MACRO_CONTENT_CATEGORY] = $categoryStr;		// 画像情報(カテゴリー)
+		$contentText = $this->convertM3ToHtml($contentText, true/*改行コードをbrタグに変換*/, $contentInfo);
+		$this->tmpl->addVar("photo_info_area", "content", $contentText);
+/*
+		if (self::$_configArray[photo_mainCommonDef::CF_USE_PHOTO_KEYWORD]){	// 画像情報(検索キーワード)を使用のとき
+		*/
+		
+		// 画像情報
+		$this->tmpl->addVar("photo_info_area", "photo_id", $this->photoId);
+		$this->tmpl->addVar("photo_info_area", "img_url", $this->getUrl($imageUrl));
+		$this->tmpl->addVar("photo_info_area", "width", $width);
+		$this->tmpl->addVar("photo_info_area", "height", $height);
+		$this->tmpl->addVar("photo_info_area", "title", $this->convertToDispString($title));
+		$this->tmpl->addVar("photo_info_area", "alt", $this->convertToDispString($alt));
+		$this->tmpl->addVar("photo_info_area", "back_url", $this->convertUrlToHtmlEntity($this->getUrl($backUrl, true/*リンク用*/)));// 「戻る」リンク
+		$this->tmpl->addVar("photo_info_area", "back_img_url", $this->getUrl($this->gEnv->getRootUrl() . self::BACK_ICON_FILE));// 「戻る」アイコン
+		$this->tmpl->addVar("photo_info_area", "icon_size", photo_mainCommonDef::BUTTON_ICON_SIZE);
+		$this->tmpl->addVar("photo_info_area", "back_title", self::BACK_BUTTON_TITLE);
+		$this->tmpl->addVar("photo_info_area", "back_alt", self::BACK_BUTTON_TITLE);
+		// スクリプト部
+		$this->tmpl->addVar('photo_info_script', 'raty_image_url', $this->getUrl($this->gEnv->getScriptsUrl() . self::RATY_IMAGE_DIR));	// jquery.raty画像パス
+		$this->tmpl->addVar("photo_info_script", "init_rate", $this->convertToDispString($row['ht_rate_average']));		// 評価値
+		$this->tmpl->addVar("photo_info_area", "comment_count", count($this->serialArray));		// コメント数
+		
+		// ハッシュキー作成
+		$postTicket = md5(time() . $this->gAccess->getAccessLogSerialNo());
+		$request->setSessionValue(M3_SESSION_POST_TICKET, $postTicket);		// セッションに保存
+		$this->tmpl->addVar("photo_info_area", "ticket", $postTicket);				// 画面に書き出し
+			
+		// ビューカウントを更新
+		if (!$this->gEnv->isSystemManageUser()){		// システム運用者以上の場合はカウントしない
+			// 詳細な参照情報
+			$this->gInstance->getAnalyzeManager()->updateContentViewCount(photo_mainCommonDef::REF_TYPE_CONTENT, $row['ht_id'], $this->currentDay, $this->currentHour);
+			
+			// 画像情報の参照数更新
+			self::$_mainDb->updatePhotoInfoViewCount($row['ht_serial']);
 		}
 	}
 	/**
@@ -684,16 +708,17 @@ class photo_mainTopWidgetContainer extends photo_mainBaseWidgetContainer
 		$postTicket = $request->trimValueOf('ticket');		// POST確認用
 		$comment = $request->trimValueOf('comment');
 		$rateValue = $request->trimIntValueOf('value', '0');
-		$ip = $this->gRequest->trimServerValueOf('REMOTE_ADDR');
+		//$ip = $this->gRequest->trimServerValueOf('REMOTE_ADDR');
+		$clientId = $this->gAccess->getClientId();			// ブラウザのクライアントIDを取得
 
 		$retValue = 0;		// 登録状況
 		if (!empty($postTicket) && $postTicket == $request->getSessionValue(M3_SESSION_POST_TICKET)){		// 正常なPOST値のとき
 			// 送信データのチェック
 			if (0 < $rateValue && $rateValue <= 5){
 				// 既に登録済みかどうか確認
-				$isRegistered = $commentDb->isExistsComment($this->photoId, $ip, $this->_langId);
+				$isRegistered = $commentDb->isExistsComment($this->photoId, $clientId, $this->_langId);
 				if (!$isRegistered){
-					$ret = $commentDb->addCommentItem($this->photoId, $this->_langId, $ip, $rateValue, $comment, $rateAverage, $newSerial);
+					$ret = $commentDb->addCommentItem($this->photoId, $this->_langId, $clientId, $rateValue, $comment, $rateAverage, $newSerial);
 					if ($ret) $ret = $commentDb->getCommentBySerial($newSerial, $row);
 					if ($ret){
 						$rateValue = $row['hr_rate_value'];		// 評価値
@@ -1390,5 +1415,26 @@ class photo_mainTopWidgetContainer extends photo_mainBaseWidgetContainer
 		}
 		return array();
 	}
+	/**
+	 * 詳細コンテンツを作成
+	 *
+	 * @param array	$contentParam		コンテンツ作成用パラメータ
+	 * @return string					作成コンテンツ
+	 */
+	function createDetailContent($contentParam)
+	{
+		$contentText = self::$_configArray[photo_mainCommonDef::CF_LAYOUT_VIEW_DETAIL];// コンテンツレイアウト(詳細表示)
+		
+		// コンテンツを作成
+		$keys = array_keys($contentParam);
+		for ($i = 0; $i < count($keys); $i++){
+			$key = $keys[$i];
+			$value = str_replace('\\', '\\\\', $contentParam[$key]);		// ##### (注意)preg_replaceで変換値のバックスラッシュが解釈されるので、あらかじめバックスラッシュを2重化しておく必要がある
+			
+			$pattern = '/' . preg_quote(M3_TAG_START . $key) . ':?(.*?)' . preg_quote(M3_TAG_END) . '/u';
+			$contentText = preg_replace($pattern, $value, $contentText);
+		}
+		return $contentText;
+	}
 }
 ?>
