@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2012 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: photo_mainDb.php 4611 2012-01-24 11:38:41Z fishbone $
+ * @version    SVN: $Id: photo_mainDb.php 5612 2013-02-07 14:32:27Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getDbPath() . '/baseDb.php');
@@ -294,7 +294,7 @@ class photo_mainDb extends BaseDb
 				$code = $row['ht_code'];				// 画像コード
 				$mimeType = $row['ht_mime_type'];		// 画像MIMEタイプ
 				$imageSize = $row['ht_image_size'];		// 画像縦横サイズ
-				$originalName = $row['ht_original_filename'];		// オリジナルファイル名
+				$originalName = $row['ht_original_filename'];		// 元のファイル名
 				$filesize = $row['ht_file_size'];					// ファイルサイズ
 				$ownerId = $row['ht_owner_id'];			// 所有者
 				$rateAverage = $row['ht_rate_average'];			// 評価値
@@ -328,7 +328,7 @@ class photo_mainDb extends BaseDb
 		$queryStr .=   'ht_camera, ';
 		$queryStr .=   'ht_location, ';
 		$queryStr .=   'ht_date, ';
-		$queryStr .=   'ht_note, ';
+		$queryStr .=   'ht_description, ';
 		$queryStr .=   'ht_license, ';
 		$queryStr .=   'ht_rate_average, ';
 		$queryStr .=   'ht_view_count, ';
@@ -603,7 +603,7 @@ class photo_mainDb extends BaseDb
 				$queryStr .=    'OR ht_name LIKE \'%' . $keyword . '%\' ';		// 画像タイトル
 				$queryStr .=    'OR ht_camera LIKE \'%' . $keyword . '%\' ';		// カメラ
 				$queryStr .=    'OR ht_location LIKE \'%' . $keyword . '%\' ';		// 撮影場所
-				$queryStr .=    'OR ht_note LIKE \'%' . $keyword . '%\' ';		// メモ
+				$queryStr .=    'OR ht_description LIKE \'%' . $keyword . '%\' ';		// メモ
 				$queryStr .=    'OR ht_keyword LIKE \'%' . $keyword . '%\' ';		// キーワード
 				$queryStr .=    'OR lu_name LIKE \'%' . $keyword . '%\') ';	// 撮影者
 			}
@@ -707,7 +707,7 @@ class photo_mainDb extends BaseDb
 				$queryStr .=    'OR ht_name LIKE \'%' . $keyword . '%\' ';		// 画像タイトル
 				$queryStr .=    'OR ht_camera LIKE \'%' . $keyword . '%\' ';		// カメラ
 				$queryStr .=    'OR ht_location LIKE \'%' . $keyword . '%\' ';		// 撮影場所
-				$queryStr .=    'OR ht_note LIKE \'%' . $keyword . '%\' ';		// メモ
+				$queryStr .=    'OR ht_description LIKE \'%' . $keyword . '%\' ';		// メモ
 				$queryStr .=    'OR ht_keyword LIKE \'%' . $keyword . '%\' ';		// キーワード
 				$queryStr .=    'OR lu_name LIKE \'%' . $keyword . '%\') ';	// 撮影者
 			}
@@ -802,7 +802,7 @@ class photo_mainDb extends BaseDb
 				$queryStr .=    'OR ht_name LIKE \'%' . $keyword . '%\' ';		// 画像タイトル
 				$queryStr .=    'OR ht_camera LIKE \'%' . $keyword . '%\' ';		// カメラ
 				$queryStr .=    'OR ht_location LIKE \'%' . $keyword . '%\' ';		// 撮影場所
-				$queryStr .=    'OR ht_note LIKE \'%' . $keyword . '%\' ';		// メモ
+				$queryStr .=    'OR ht_description LIKE \'%' . $keyword . '%\' ';		// メモ
 				$queryStr .=    'OR ht_keyword LIKE \'%' . $keyword . '%\' ';		// キーワード
 				$queryStr .=    'OR lu_name LIKE \'%' . $keyword . '%\') ';	// 撮影者
 			}
@@ -896,7 +896,7 @@ class photo_mainDb extends BaseDb
 				$queryStr .=    'OR ht_name LIKE \'%' . $keyword . '%\' ';		// 画像タイトル
 				$queryStr .=    'OR ht_camera LIKE \'%' . $keyword . '%\' ';		// カメラ
 				$queryStr .=    'OR ht_location LIKE \'%' . $keyword . '%\' ';		// 撮影場所
-				$queryStr .=    'OR ht_note LIKE \'%' . $keyword . '%\' ';		// メモ
+				$queryStr .=    'OR ht_description LIKE \'%' . $keyword . '%\' ';		// メモ
 				$queryStr .=    'OR ht_keyword LIKE \'%' . $keyword . '%\' ';		// キーワード
 				$queryStr .=    'OR lu_name LIKE \'%' . $keyword . '%\') ';	// 撮影者
 			}
